@@ -1,30 +1,40 @@
 """GDACS feed entry."""
 from collections.abc import Mapping
 from datetime import datetime
-from typing import Optional, Tuple, Union, List, Type
+from typing import List, Optional, Tuple, Type, Union
 
 import dateparser
 from aio_georss_client.feed_entry import FeedEntry
 from aio_georss_client.xml_parser.feed_item import FeedItem
-from aio_georss_client.xml_parser.geometry import Geometry, Polygon, Point
+from aio_georss_client.xml_parser.geometry import Geometry, Point, Polygon
 
-from .consts import (ATTRIBUTION, EVENT_TYPE_MAP, XML_ATTRIBUTE_VALUE,
-                     XML_TAG_GDACS_ALERT_LEVEL, XML_TAG_GDACS_COUNTRY,
-                     XML_TAG_GDACS_DURATION_IN_WEEK, XML_TAG_GDACS_EVENT_NAME,
-                     XML_TAG_GDACS_EVENT_TYPE, XML_TAG_GDACS_FROM_DATE,
-                     XML_TAG_GDACS_ICON, XML_TAG_GDACS_IS_CURRENT,
-                     XML_TAG_GDACS_POPULATION, XML_TAG_GDACS_SEVERITY,
-                     XML_TAG_GDACS_TEMPORARY, XML_TAG_GDACS_TO_DATE,
-                     XML_TAG_GDACS_VERSION, XML_TAG_GDACS_VULNERABILITY,
-                     XML_TEXT, XML_TAG_GDACS_EVENT_ID)
+from .consts import (
+    ATTRIBUTION,
+    EVENT_TYPE_MAP,
+    XML_ATTRIBUTE_VALUE,
+    XML_TAG_GDACS_ALERT_LEVEL,
+    XML_TAG_GDACS_COUNTRY,
+    XML_TAG_GDACS_DURATION_IN_WEEK,
+    XML_TAG_GDACS_EVENT_ID,
+    XML_TAG_GDACS_EVENT_NAME,
+    XML_TAG_GDACS_EVENT_TYPE,
+    XML_TAG_GDACS_FROM_DATE,
+    XML_TAG_GDACS_ICON,
+    XML_TAG_GDACS_IS_CURRENT,
+    XML_TAG_GDACS_POPULATION,
+    XML_TAG_GDACS_SEVERITY,
+    XML_TAG_GDACS_TEMPORARY,
+    XML_TAG_GDACS_TO_DATE,
+    XML_TAG_GDACS_VERSION,
+    XML_TAG_GDACS_VULNERABILITY,
+    XML_TEXT,
+)
 
 
 class GdacsFeedEntry(FeedEntry):
     """GDACS feed entry."""
 
-    def __init__(self,
-                 home_coordinates: Tuple[float, float],
-                 feature: FeedItem):
+    def __init__(self, home_coordinates: Tuple[float, float], feature: FeedItem):
         """Initialise this service."""
         super().__init__(home_coordinates, feature)
 
@@ -47,16 +57,14 @@ class GdacsFeedEntry(FeedEntry):
     def alert_level(self) -> Optional[str]:
         """Return the alert level of this entry."""
         if self._rss_entry:
-            return self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_ALERT_LEVEL)
+            return self._rss_entry.get_additional_attribute(XML_TAG_GDACS_ALERT_LEVEL)
         return None
 
     @property
     def country(self) -> Optional[str]:
         """Return the country of this entry."""
         if self._rss_entry:
-            return self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_COUNTRY)
+            return self._rss_entry.get_additional_attribute(XML_TAG_GDACS_COUNTRY)
         return None
 
     @property
@@ -67,7 +75,8 @@ class GdacsFeedEntry(FeedEntry):
             # 1 = Second week
             # etc.
             duration_in_week = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_DURATION_IN_WEEK)
+                XML_TAG_GDACS_DURATION_IN_WEEK
+            )
             if duration_in_week:
                 return int(duration_in_week)
         return None
@@ -76,8 +85,7 @@ class GdacsFeedEntry(FeedEntry):
     def event_id(self) -> Optional[int]:
         """Return the event id of this entry."""
         if self._rss_entry:
-            event_id = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_EVENT_ID)
+            event_id = self._rss_entry.get_additional_attribute(XML_TAG_GDACS_EVENT_ID)
             if event_id:
                 return int(event_id)
         return None
@@ -86,16 +94,14 @@ class GdacsFeedEntry(FeedEntry):
     def event_name(self) -> Optional[str]:
         """Return the event name of this entry."""
         if self._rss_entry:
-            return self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_EVENT_NAME)
+            return self._rss_entry.get_additional_attribute(XML_TAG_GDACS_EVENT_NAME)
         return None
 
     @property
     def event_type_short(self) -> Optional[str]:
         """Return the short event type of this entry."""
         if self._rss_entry:
-            return self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_EVENT_TYPE)
+            return self._rss_entry.get_additional_attribute(XML_TAG_GDACS_EVENT_TYPE)
         return None
 
     @property
@@ -111,7 +117,8 @@ class GdacsFeedEntry(FeedEntry):
         """Return the from date of this entry."""
         if self._rss_entry:
             from_date = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_FROM_DATE)
+                XML_TAG_GDACS_FROM_DATE
+            )
             if from_date:
                 return dateparser.parse(from_date)
         return None
@@ -120,8 +127,7 @@ class GdacsFeedEntry(FeedEntry):
     def icon_url(self) -> Optional[str]:
         """Return the icon url of this entry."""
         if self._rss_entry:
-            return self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_ICON)
+            return self._rss_entry.get_additional_attribute(XML_TAG_GDACS_ICON)
         return None
 
     @property
@@ -129,7 +135,8 @@ class GdacsFeedEntry(FeedEntry):
         """Return if this entry is current."""
         if self._rss_entry:
             is_current = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_IS_CURRENT)
+                XML_TAG_GDACS_IS_CURRENT
+            )
             if is_current:
                 return FeedEntry._string2boolean(is_current)
         return None
@@ -139,7 +146,8 @@ class GdacsFeedEntry(FeedEntry):
         """Return the population of this entry."""
         if self._rss_entry:
             population = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_POPULATION)
+                XML_TAG_GDACS_POPULATION
+            )
             if population:
                 if isinstance(population, Mapping):
                     if XML_TEXT in population:
@@ -152,8 +160,7 @@ class GdacsFeedEntry(FeedEntry):
     def severity(self) -> Optional[str]:
         """Return the severity of this entry."""
         if self._rss_entry:
-            severity = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_SEVERITY)
+            severity = self._rss_entry.get_additional_attribute(XML_TAG_GDACS_SEVERITY)
             if severity:
                 if isinstance(severity, Mapping):
                     if XML_TEXT in severity:
@@ -167,7 +174,8 @@ class GdacsFeedEntry(FeedEntry):
         """Return if this entry is temporary."""
         if self._rss_entry:
             temporary = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_TEMPORARY)
+                XML_TAG_GDACS_TEMPORARY
+            )
             if temporary:
                 return FeedEntry._string2boolean(temporary)
         return None
@@ -176,8 +184,7 @@ class GdacsFeedEntry(FeedEntry):
     def to_date(self) -> Optional[datetime]:
         """Return the to date of this entry."""
         if self._rss_entry:
-            to_date = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_TO_DATE)
+            to_date = self._rss_entry.get_additional_attribute(XML_TAG_GDACS_TO_DATE)
             if to_date:
                 return dateparser.parse(to_date)
         return None
@@ -186,8 +193,7 @@ class GdacsFeedEntry(FeedEntry):
     def version(self) -> Optional[int]:
         """Return the version of this entry."""
         if self._rss_entry:
-            version = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_VERSION)
+            version = self._rss_entry.get_additional_attribute(XML_TAG_GDACS_VERSION)
             if version:
                 return int(version)
         return None
@@ -197,7 +203,8 @@ class GdacsFeedEntry(FeedEntry):
         """Return the vulnerability of this entry."""
         if self._rss_entry:
             vulnerability = self._rss_entry.get_additional_attribute(
-                XML_TAG_GDACS_VULNERABILITY)
+                XML_TAG_GDACS_VULNERABILITY
+            )
             if vulnerability:
                 if isinstance(vulnerability, Mapping):
                     # 1. See if there is a textual value.
